@@ -8,5 +8,5 @@ from setuptools import setup
 
 setup(
     app=["hello.py"],
-    setup_requires=["py2app"],
+    setup_requires=["py2app", "Pillow"],
 )
